@@ -56,7 +56,7 @@ model* lda(int *i, int *j, int *v, int total,
 
 extern "C" {
 
-SEXP returnObjectGibbsLDA(SEXP ans, model * model) {
+static SEXP returnObjectGibbsLDA(SEXP ans, model * model) {
   SEXP tp, I, J, V, wordassign, nms, z;
   int total, i, j, d;
   int *It, *Jt, *word_new;
